@@ -93,6 +93,7 @@ class account():
         self.osso_c = osso_c
         self.api = None
         self.connect()
+        self.locationSetup=False
         self.dmnotify = pynotify.Notification("Witter","You have new DMs")
         self.dmnotify.add_action("clicked","Show DMs", self.dm_callback)
         #TODO move this and check if the call can be put on background thread from main loop
@@ -111,7 +112,7 @@ class account():
         self.control.connect("gpsd-stopped", self.on_stop, loop)
  
         gobject.idle_add(self.start_location, self.control)
- 
+        self.locationSetup=True
         loop.run()
 
     def stopLocation(self):
@@ -139,22 +140,32 @@ class account():
             print "Connection working ok"
             return True
 
+
+    def getProfileInfo(self, username):
+        print "getting profile info"
+        user = self.api.GetUser(username)
+        return user
+        
     def setProfileInfo(self):
-        user = self.api.GetUser(self.accountdata.username)
-        self.controller.ui.profileTweetsLabel.set_text("TweetCount: " +str(user.GetStatusesCount()))
-        self.controller.ui.profileFollowerCount.set_text("Followers: "+str(user.GetFollowersCount()))
-        self.controller.ui.profileFollowingCount.set_text("Following: " +str(user.GetFriendsCount()))
-        self.controller.ui.accountNameLabel.set_text(self.accountdata.username)
-        self.controller.ui.profileLastTweet.set_text(user.GetStatus().GetText())
-        if (user.GetStatus().GetPlace() != None):
-            self.controller.ui.profileLocation.set_text(user.GetStatus().GetPlace().name)
-        else:
-            self.controller.ui.profileLocation.set_text(user.GetLocation())
-            
-        avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
-        avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
-        #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
-        self.controller.ui.profileImage.set_from_pixbuf(avatar)  
+        try:
+            user = self.getProfileInfo(self.accountdata.username)
+            self.controller.ui.profileTweetsLabel.set_text("TweetCount: " +str(user.GetStatusesCount()))
+            self.controller.ui.profileFollowerCount.set_text("Followers: "+str(user.GetFollowersCount()))
+            self.controller.ui.profileFollowingCount.set_text("Following: " +str(user.GetFriendsCount()))
+            self.controller.ui.accountNameLabel.set_text(self.accountdata.username)
+            self.controller.ui.profileLastTweet.set_text(user.GetStatus().GetText())
+            if (user.GetStatus().GetPlace() != None):
+                self.controller.ui.profileLocation.set_text(user.GetStatus().GetPlace().name)
+            else:
+                if (user.GetLocation() != None):
+                    self.controller.ui.profileLocation.set_text(user.GetLocation())
+                
+            avatar, loaded = self.retrieve_avatar(user.GetProfileImageUrl(), str(user.id)+".jpg")   
+            avatar = avatar.scale_simple(90, 90, gtk.gdk.INTERP_BILINEAR)
+            #self.controller.ui.profileImage.set_from_file("/home/user/.witterPics/" + self.accountdata.servicename + "/" + str(user.id)+".jpg")
+            self.controller.ui.profileImage.set_from_pixbuf(avatar)  
+        except AttributeError:
+            print "Failed to load profile info" 
             
     def getAccountData(self):
         return self.accountdata
@@ -904,11 +915,12 @@ class account():
         #see if we have just an empty string (eg eroneous button press)
         if (tweet == ""):
             return False
-        if (self.controller.location):
-            if self.device.fix:
-                if self.device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
-                    print "lat = %f, long = %f" % self.device.fix[4:6]
-                    self.lat, self.long = self.device.fix[4:6]
+        if (self.controller.location & self.locationSetup):
+            if self.device:
+                if self.device.fix:
+                    if self.device.fix[1] & location.GPS_DEVICE_LATLONG_SET:
+                        print "lat = %f, long = %f" % self.device.fix[4:6]
+                        self.lat, self.long = self.device.fix[4:6]
             
         #if (self.controller.location):
         #    self.updateLocation()
