@@ -77,7 +77,7 @@ class Witter():
     #first an init method to set everything up    
     def __init__(self):
         #version of witter
-        self.version = "0.3.5"
+        self.version = "0.3.6"
         #object holding witter config
         self.config = None
         #defaults for auto-refresh
@@ -1094,32 +1094,7 @@ class Witter():
                 print "switching active account to " + account.getUsername()
                 self.activeAccount = account
                 self.ui.setWindowTitlePrefix("Witter(" + self.activeAccount.getUsername() + ")")
-                curView = self.ui.getCurrentView()
-                if (curView == self.ui.TIMELINE_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getTimeline(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - timeline")
-                if (curView == self.ui.MENTIONS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getMentionsList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - mentions")
-                if (curView == self.ui.DM_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getDmsList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - DMs")
-                if (curView == self.ui.SEARCH_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getSearchList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - search")
-                if (curView == self.ui.FRIENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getFriendsList(),0)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - friends")
-                if (curView == self.ui.TRENDS_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getTrendsList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - trends")
-                if (curView == self.ui.PUBLIC_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getPublicList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - public")
-                if (curView == self.ui.USERHIST_VIEW):
-                    self.ui.setActiveListStore(self.activeAccount.getUserHistoryList(),4)
-                    self.ui.setWindowTitle("Witter(" + self.activeAccount.getUsername() + ")" + " - user history")
-
+                
 
 
     def addNewAccount(self, accountData):
@@ -1174,7 +1149,7 @@ class Witter():
                 if ((self.ui.activeWin !="home") & (self.ui.activeWin != None)):
                     self.ui.toggleviewto(self.ui.activeWin)
                 
-                self.ui.hide_portrait_keyboard()
+                
                 self.ui.current_orientation = 'landscape'
          else:
             print "not top most window, not rotating"
